StaticSecret

Struct StaticSecret 

pub struct StaticSecret(/* private fields */);
A Diffie-Hellman secret key that can be used to compute multiple SharedSecrets.

This type is identical to the EphemeralSecret type, except that the StaticSecret::diffie_hellman method does not consume the secret key, and the type provides serialization methods to save and load key material. This means that the secret may be used multiple times (but does not have to be).

Warning

If you’re uncertain about whether you should use this, then you likely should not be using this. Our strongly recommended advice is to use EphemeralSecret at all times, as that type enforces at compile-time that secret keys are never reused, which can have very serious security implications for many protocols.

Implementations

Source

impl StaticSecret

pub fn diffie_hellman(&self, their_public: &PublicKey) -> SharedSecret

Perform a Diffie-Hellman key agreement between self and their_public key to produce a SharedSecret.

pub fn new<T>(csprng: T) -> StaticSecret
where T: RngCore + CryptoRng,

Generate an x25519 key.

pub fn to_bytes(&self) -> [u8; 32]

Extract this key’s bytes for serialization.