[−][src]Struct keybear_core::crypto::StaticSecret
A Diffie-Hellman secret key that can be used to compute multiple SharedSecrets.
This type is identical to the EphemeralSecret type, except that the
StaticSecret::diffie_hellman method does not consume the secret key, and the type provides
serialization methods to save and load key material. This means that the secret may be used
multiple times (but does not have to be).
Some protocols, such as Noise, already handle the static/ephemeral distinction, so the
additional guarantees provided by EphemeralSecret are not helpful or would cause duplicate
code paths. In this case, it may be useful to
use x25519_dalek::StaticSecret as SecretKey;
since the only difference between the two is that StaticSecret does not enforce at
compile-time that the key is only used once.
Implementations
impl StaticSecret[src]
pub fn diffie_hellman(&self, their_public: &PublicKey) -> SharedSecret[src]
Perform a Diffie-Hellman key agreement between self and
their_public key to produce a SharedSecret.
pub fn new<T>(csprng: T) -> StaticSecret where
T: RngCore + CryptoRng, [src]
T: RngCore + CryptoRng,
Generate an x25519 key.
pub fn to_bytes(&self) -> [u8; 32][src]
Extract this key's bytes for serialization.